from .Diagnostics_Fixture import FixtureDiagnostic
from tediagtoolbox.diag_manager import DiagManager
from tediagtoolbox.enum_types import DiagProtocol
from mtf.diag_port.diag_servers.doip_server import DoipServer
from xtr import logging, Severity
logger = logging.getLogger(__name__)


class TestDiagnostics(FixtureDiagnostic):
    def setUp(self):

        logger.info("Setup test case")

    def tearDown(self):

        logger.info("Tear down test case")

    def test_diagnostics(self):

        DOIP_PORT = 98700
        LOGICAL_ADDRESS = 0x15

        # create DoIP server and assign properties
        SERVER_IP = '127.0.0.1'
        server = DoipServer(SERVER_IP, port=DOIP_PORT, logical_address=LOGICAL_ADDRESS)
        server.vin = "kolJP1050H159753y49".encode('utf-8')
        server.eid = bytes.fromhex("00123456beef22")
        server.gid = bytes.fromhex("00789456ef22")
        server.start()

        # create doip client
        TESTER_ADDRESS = 0x5de
        #creating controllers instances directly
        diag_controller = EthDiagController(source_address=TESTER_ADDRESS, target_address=LOGICAL_ADDRESS,
                                            destination_ip=SERVER_IP,
                                            diag_protocol=DiagProtocol.DoIP, protocol_version=0x03)

        # send request and expect positive response
        server.positive_responding = True
        server.positive_response_data = bytes([0x3, 0x4])
        resp = diag_controller.sync_send_interpret_response([0x22, 0x1, 0x2])
        diag_controller.client.read_data_by_identifier(0x12)
        self.assertTrue(resp.positive, Severity.BLOCKER)

        # send request and expect negative response
        server.positive_responding = False
        resp = diag_controller.sync_send_interpret_response([0x22, 0x1, 0x2])
        self.assertFalse(resp.positive, Severity.BLOCKER)

        server.stop()
